Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CpuManager ¶
type CpuManager struct {
// contains filtered or unexported fields
}
func NewCpuManager ¶
func NewCpuManager(emu uc.Unicorn, mode int, stackAddress, stackSize, heapAddress, heapSize uint64) *CpuManager
func (*CpuManager) PopContext ¶
func (self *CpuManager) PopContext() interface{}
func (*CpuManager) PrintStack ¶
func (self *CpuManager) PrintStack(size int)
func (*CpuManager) PushContext ¶
func (self *CpuManager) PushContext(context interface{})
func (*CpuManager) ReadRegisters ¶
func (self *CpuManager) ReadRegisters() interface{}
type HeapManager ¶
type HeapManager struct {
// contains filtered or unexported fields
}
func NewHeap ¶
func NewHeap(base uint64) *HeapManager
func (*HeapManager) Free ¶
func (self *HeapManager) Free(addr uint64) uint64
func (*HeapManager) MMap ¶
func (self *HeapManager) MMap(start, size uint64) (uint64, uint64)
Map (length) bytes preferably at (start) this will map memory aligned to 4k boundaries, and round up size to 4k multiples
func (*HeapManager) Malloc ¶
func (self *HeapManager) Malloc(size uint64) uint64
func (*HeapManager) ReAlloc ¶
func (self *HeapManager) ReAlloc(addr uint64, newsize uint64) (uint64, uint64)
given a previously allocated memory block, copy contents to new block and increase size
func (*HeapManager) Size ¶
func (self *HeapManager) Size(addr uint64) uint64
Size returns the size of a particular heap entry, returns 0 of heap entry is not found
type LogManager ¶
type LogManager struct {
// contains filtered or unexported fields
}
func NewLogManager ¶
func NewLogManager() *LogManager
func (*LogManager) AddIoc ¶
func (self *LogManager) AddIoc(key, value string)
type Registers32 ¶
type Registers32 struct {
Eip uint32
Esp uint32
Eax uint32
Ebx uint32
Ecx uint32
Edx uint32
Esi uint32
Edi uint32
Ebp uint32
EipVal uint32
EspVal uint32
EaxVal uint32
EbxVal uint32
EcxVal uint32
EdxVal uint32
EsiVal uint32
EdiVal uint32
EbpVal uint32
}
func (*Registers32) String ¶
func (self *Registers32) String() string
type Registers64 ¶
type Registers64 struct {
Rip uint64
Rsp uint64
Rax uint64
Rbx uint64
Rcx uint64
Rdx uint64
Rsi uint64
Rdi uint64
Rbp uint64
R8 uint64
R9 uint64
R10 uint64
R11 uint64
R12 uint64
R13 uint64
R14 uint64
R15 uint64
}
func (*Registers64) String ¶
func (self *Registers64) String() string
Click to show internal directories.
Click to hide internal directories.